@@ -24,12 +24,15 @@ pub enum MyError {
         source: askama::Error,
     },
     #[error("Failed to read config file.")]
-    ConfigReadError{
-        source: std::io::Error,
-    },
+    ConfigReadError { source: std::io::Error },
     #[error("Failed to parse config file.")]
     ConfigParseError {
         #[from]
         source: toml::de::Error,
-    }
-}
\ No newline at end of file
+    },
+    #[error("Not valid UTF-8")]
+    BadUtf8 {
+        #[from]
+        source: std::str::Utf8Error,
+    },
+}
